@@ -3,11 +3,12 @@ import json
 import threading
 import datetime
 from abc import ABC, abstractmethod
-from typing import List
+from typing import List, Callable
 
 import digi
 from digi.data import logger, zjson
-from digi.data import zed
+from digi.data import zed, sync
+from digi.data import router
 
 
 class Pool(ABC):
@@ -24,6 +25,11 @@ class Pool(ABC):
     def query(self, query: str):
         raise NotImplementedError
 
+    @abstractmethod
+    def watch(self, once: Callable, *,
+              branch: str = "main"):
+        raise NotImplementedError
+
     @abstractmethod
     def create_branch_if_not_exist(self, query: str):
         raise NotImplementedError
@@ -51,21 +57,23 @@ class ZedPool(Pool):
                 o["ts"] = now
             data = "".join(zjson.encode(objects))
         elif encoding == "json":
-            now = zjson.encode_datetime(now)  # as str
+            zjson_now = zjson.encode_datetime(now)  # as str
             for o in objects:
                 if "event_ts" not in o:
-                    o["event_ts"] = o.get("ts", now)
-                o["ts"] = now
+                    o["event_ts"] = o.get("ts", zjson_now)
+                o["ts"] = zjson_now
             data = "\n".join(json.dumps(o) for o in objects)
         else:
             raise NotImplementedError
 
         self.lock.acquire()
         try:
+            # TBD better source name
+            meta = json.dumps({f"{digi.name}": zjson.encode_datetime(now)})
             self.client.load(self.name, data,
                              branch_name=branch,
                              commit_author=digi.name,
-                             meta="")
+                             meta=meta)
             # TBD load from digi also commits source ts in meta
         except Exception as e:
             digi.logger.warning(f"unable to load "
@@ -73,12 +81,27 @@ class ZedPool(Pool):
         finally:
             self.lock.release()
 
-    def query(self, query):
+    def query(self, query: str):
+        if query != "":
+            query = f"| {query}"
+        query = f"from {self.name} {query}"
         return self.client.query(query)
 
+    def watch(self, fn: Callable, *,
+              in_flow: str = "",
+              eoio: bool = True,
+              ):
+        """Watch changes of the main pool and run UDF."""
+        source = f"{self.name}@main"
+        return sync.Watch(fn,
+                          sources=[source],
+                          eoio=eoio,
+                          in_flow=in_flow)
+
     def create_branch_if_not_exist(self, branch: str):
         if not self.client.branch_exist(self.name, branch):
             self.client.create_branch(self.name, branch)
+            self.load([router.Egress.INIT], branch=branch)
 
 
 def pool_name(g, v, r, n, ns):
