@@ -14,7 +14,6 @@ class Router:
 class Ingress:
     def __init__(self):
         self._syncs = dict()
-        self.sources = dict()
 
     def start(self):
         for name, _sync in self._syncs.items():
@@ -26,6 +25,9 @@ class Ingress:
         self._syncs = dict()
 
         for name, ig in config.items():
+            if ig.get("pause", False):
+                continue
+
             sources = list()
             flow, flow_agg = ig.get("flow", ""), \
                              ig.get("flow_agg", "")
@@ -33,6 +35,7 @@ class Ingress:
                 sources += util.parse_source(s)
             for s in ig.get("sources", []):
                 sources += util.parse_source(s)
+
             # TBD deduplicate sources
             if len(sources) == 0:
                 continue
@@ -41,12 +44,14 @@ class Ingress:
                 _out_flow = flow_lib.refresh_ts
             else:
                 _out_flow = f"{flow_agg} | {flow_lib.refresh_ts}"
+
             _sync = sync.Sync(
                 sources=sources,
                 in_flow=flow,
                 out_flow=_out_flow,
                 dest=digi.pool.name,
                 eoio=ig.get("eoio", True),
+                patch_source=ig.get("patch_source", False),
                 client=zed.Client(),
                 owner=digi.name,
             )
@@ -61,8 +66,16 @@ class Ingress:
         self.update(config=config)
         self.start()
 
+    @staticmethod
+    def _any_source():
+        # TBD fetch all sources - digi and egresses
+        # for digis that are mounted
+        raise NotImplementedError
+
 
 class Egress:
+    INIT = {"__meta": "init"}
+
     def __init__(self):
         self._syncs = dict()
 
@@ -76,11 +89,15 @@ class Egress:
         self._syncs = dict()
 
         for name, ig in config.items():
+            if ig.get("driver_managed", False) \
+                    or ig.get("pause", False):
+                continue
+
             flow = ig.get("flow", "")
             _sync = sync.Sync(
                 sources=[digi.pool.name],
                 in_flow=flow,
-                out_flow=flow_lib.refresh_ts,
+                out_flow=f"{flow_lib.drop_meta} | {flow_lib.refresh_ts}",
                 dest=f"{digi.pool.name}@{name}",
                 eoio=ig.get("eoio", True),
                 client=zed.Client(),
@@ -110,12 +127,12 @@ def do_mount(model, diff):
         digi.router.ingress.restart(config)
 
 
-@digi.on.ingress
+@digi.on.ingress(prio=128)  # handler runs at last XXX sys.maxsize
 def do_ingress(config):
     digi.router.ingress.restart(config)
 
 
-@digi.on.egress
+@digi.on.egress(prio=128)
 def do_egress(config):
     digi.router.egress.restart(config)
 
