@@ -36,8 +36,9 @@ class __Reconciler:
         self._logger = digi.logger
 
         self.skip_gen = -1
-        self.count = 0
+        self._skip = True
         self.last_seen_gen = -1
+        self.count = 0
 
         # handler info (e.g., priority) are used to
         # generate the self.handlers upon handler updates;
@@ -55,11 +56,13 @@ class __Reconciler:
         # read-only copy to be used in external application
         self._view = dict()
 
+        self._data_watches = dict()
+
     def run(self, spec, old, diff, *args, **kwargs):
         spec = dict(spec)
         proc_spec = dict(spec)
 
-        self._view = spec
+        self._view = proc_spec
         self._update_handler_info(spec, diff)
         self._compile_handler()
 
@@ -77,6 +80,7 @@ class __Reconciler:
                         obs=proc_spec.get("obs", {}),
                         back_prop=get_back_prop(diff),
                         diff=diff,
+                        meta=proc_spec.get("meta", {}),
                     )
                     self._pending_handler.add(id(fn))
                 except Exception as e:
@@ -184,6 +188,29 @@ class __Reconciler:
     def clear_pending(self):
         self._pending_handler.clear()
 
+    def add_data_watch(self, name, watch):
+        self._data_watches[name] = watch
+
+    def start_data_watch(self):
+        for name, watch in self._data_watches.items():
+            # TBD check if this egress is on the model, if not
+            #  do digi.model.patch()
+            # TBD we assume egress name is the same as watch's
+            digi.pool.create_branch_if_not_exist(name)
+            watch.start()
+            digi.logger.info(f"data watch {name} started")
+
+    def do_not_skip(self):
+        """Set to ensure the next reconciliation loop won't be
+        skipped even if the last generation is done by the digi.
+        The flag is reset upon the should_skip() call."""
+        self._skip = False
+
+    def should_skip(self):
+        skip = self._skip
+        self._skip = True
+        return skip
+
 
 def safe_lookup(d: dict, path: tuple):
     if path == (".",):
