@@ -4,7 +4,6 @@ import time
 import asyncio
 import contextlib
 import threading
-import datetime
 
 import digi
 import inflection
@@ -93,6 +92,9 @@ def trim_default_space(n):
     return n.replace("default/", "")
 
 
+trim_namespace = trim_default_namespace = trim_default_space
+
+
 def simple_name(n):
     return trim_default_space(n)
 
@@ -169,6 +171,13 @@ def gvr(g, v, r) -> str:
     return f"{g}/{v}/{r}"
 
 
+def gvr_from_kind(kind, g=digi.g, v=digi.v):
+    return f"{g}/{v}/{inflection.pluralize(kind)}"
+
+
+gvr_of = gvr_from_kind
+
+
 def is_gvr(s: str) -> bool:
     return len(s.split("/")) == 3
 
@@ -282,7 +291,7 @@ def put(path, src, target, transform=lambda x: x):
 
 
 def deep_get(d: dict, path: Union[str, Iterable], default=None) -> Any:
-    """accepts paths in form root.'digi.dev/test'.control.power"""
+    """Can accept paths in form root.'digi.dev/test'.control.power"""
     if "'" in path or '"' in path:
         path = path.replace('"', "'")
         parsed = list()
@@ -459,28 +468,73 @@ def parse_auri(s: str) -> Auri or None:
     return Auri(**parsed)
 
 
-class Loader(threading.Thread):
-    def __init__(self, load_fn: callable, load_interval: float = 1):
+class Loop(threading.Thread):
+    def __init__(self, loop_fn: callable,
+                 loop_interval: float = 1, *,
+                 loop_interval_fn: Callable = None,
+                 ):
         threading.Thread.__init__(self)
-        self.load_fn = load_fn
-        self.load_interval = load_interval
+        self.loop_fn = loop_fn
+        self.loop_interval = loop_interval
+        self.loop_interval_fn: Callable = loop_interval_fn
         self._stop_flag = threading.Event()
 
     def run(self):
         self._stop_flag.clear()
         while not self._stop_flag.is_set():
-            self.load_fn()
-            time.sleep(self.load_interval)
+            self.loop_fn()
+            if self.loop_interval_fn is None:
+                i = self.loop_interval
+            else:
+                i = self.loop_interval_fn()
+            time.sleep(i)
 
     def stop(self):
         self._stop_flag.set()
 
-    def reset(self, load_interval: float = None) -> None:
-        if load_interval is not None:
-            self.load_interval = load_interval
+    def reset(self, loop_interval: float = None,
+              loop_interval_fn: Callable = None) -> None:
+        if loop_interval is not None:
+            self.loop_interval = loop_interval
+            self.loop_interval_fn = loop_interval_fn
         self.stop()
 
 
+class Loader(Loop):
+    def __init__(self, load_fn: callable,
+                 load_interval: float = 1, *,
+                 load_interval_fn: Callable = None,
+                 ):
+        super().__init__(loop_fn=load_fn,
+                         loop_interval=load_interval,
+                         loop_interval_fn=load_interval_fn)
+
+    def reset(self, load_interval: float = None,
+              load_interval_fn: Callable = None) -> None:
+        super().reset(loop_interval=load_interval,
+                      loop_interval_fn=load_interval_fn)
+
+
+_report_loops = dict()
+
+
+def report_loop(fn: Callable):
+    global _report_loops
+    _report_loops[fn.__name__] = Loader(load_fn=fn)
+
+    @digi.on.meta
+    def do_meta(meta):
+        i = meta.get("report_interval", -1)
+        _report_loops[fn.__name__].stop()
+        if i > 0:
+            _loop = digi.util.Loader(
+                load_fn=fn,
+                load_interval=i,
+            )
+            _report_loops[fn.__name__] = _loop
+            _loop.start()
+
+
 def name_from_auri(auri: tuple):
     return auri[3]
 
